import * as i0 from '@angular/core';
import { Component, ChangeDetectorRef, Input, ViewChild, Injectable, NgModule } from '@angular/core';
import { HammerGestureConfig, BrowserModule, HammerModule, HAMMER_GESTURE_CONFIG } from '@angular/platform-browser';
import * as Hammer from 'hammerjs';

class HammerjsCarouselComponent {
    constructor(cdRef) {
        this.cdRef = cdRef;
        this.maxNumberOfVisibileInPagination = 15;
        this.activeSlideIndex = 0;
        this.sensitivity = 10;
    }
    get slides() {
        return this.slidesInternal;
    }
    set slides(value) {
        this.slidesInternal = value;
        if (this.slides != null) {
            this.slideCount = this.slides.length;
        }
        else {
            this.slideCount = 0;
        }
    }
    get slidesForPagination() {
        if (this.slides == null) {
            return null;
        }
        if (this.slides.length > this.maxNumberOfVisibileInPagination) {
            if (this.activeSlideIndex === this.slides.length - 1) {
                return this.slides.slice(this.activeSlideIndex - (this.maxNumberOfVisibileInPagination - 1), this.activeSlideIndex + 2);
            }
            if (this.activeSlideIndex > this.maxNumberOfVisibileInPagination - 2) {
                return this.slides.slice(this.activeSlideIndex - (this.maxNumberOfVisibileInPagination - 2), this.activeSlideIndex + 2);
            }
            return this.slides.slice(0, this.maxNumberOfVisibileInPagination);
        }
        return this.slides;
    }
    ngOnInit() {
        this.isTouchDevice = 'ontouchstart' in window;
    }
    ngAfterViewChecked() {
        const sliderWrapperElement = this.sliderWrapper.nativeElement;
        this.width = sliderWrapperElement.offsetWidth;
        this.sensitivity = this.width / 40;
        this.cdRef.detectChanges();
    }
    onPan(e) {
        if (e.velocityX === 0 || Math.abs(e.velocityY) > Math.abs(e.velocityX)) {
            // Vertical scroll
            return;
        }
        const percentage = 100 / this.slideCount * e.deltaX / window.innerWidth;
        const transformPercentage = percentage - 100 / this.slideCount * this.activeSlideIndex;
        this.sliderTransformStyle = 'translateX( ' + transformPercentage + '% )';
        if (e.isFinal) {
            if (e.velocityX > 1) {
                this.goToSlideIndex(this.activeSlideIndex - 1);
            }
            else if (e.velocityX < -1) {
                this.goToSlideIndex(this.activeSlideIndex + 1);
            }
            else {
                if (percentage <= -(this.sensitivity / this.slideCount)) {
                    this.goToSlideIndex(this.activeSlideIndex + 1);
                }
                else if (percentage >= (this.sensitivity / this.slideCount)) {
                    this.goToSlideIndex(this.activeSlideIndex - 1);
                }
                else {
                    this.goToSlideIndex(this.activeSlideIndex);
                }
            }
        }
    }
    previousSlide() {
        const slideIndex = this.activeSlideIndex - 1;
        if (slideIndex < 0) {
            this.goToSlideIndex(this.slideCount - 1);
        }
        else {
            this.goToSlideIndex(slideIndex);
        }
    }
    nextSlide() {
        const slideIndex = this.activeSlideIndex + 1;
        if (slideIndex === this.slideCount) {
            this.goToSlideIndex(0);
        }
        else {
            this.goToSlideIndex(slideIndex);
        }
    }
    goToSlide(slide) {
        this.goToSlideIndex(this.slides.indexOf(slide));
    }
    goToSlideIndex(slideIndex) {
        if (slideIndex < 0) {
            this.activeSlideIndex = 0;
        }
        else if (slideIndex > this.slideCount - 1) {
            this.activeSlideIndex = this.slideCount - 1;
        }
        else {
            this.activeSlideIndex = slideIndex;
        }
        this.isAnimating = true;
        const percentage = -(100 / this.slideCount) * this.activeSlideIndex;
        this.sliderTransformStyle = 'translateX(' + percentage + '%)';
        clearTimeout(this.animatingTimeout);
        this.animatingTimeout = setTimeout(() => this.isAnimating = false, 400);
    }
    isActive(slide) {
        return this.slides[this.activeSlideIndex] === slide;
    }
    getWidthStyle() {
        if (this.width == null) {
            return null;
        }
        return (this.width / 13) + 'px';
    }
    getMarginStyle() {
        if (this.width == null) {
            return null;
        }
        return (this.width / 30) + 'px';
    }
}
HammerjsCarouselComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'hammerjs-carousel',
                template: `
  <div class="slider-wrapper" #sliderWrapper>
    <div class="slider" (pan)="onPan($event)" [style.transform]="sliderTransformStyle" [style.width]="slideCount + '00%'"
         [ngClass]="{ 'is-animating': isAnimating }">
      <div class="slider-panel" *ngFor="let slide of slides" [style.background-image]="'url(' + slide + ')'"></div>
    </div>
    <div class="slider-button left" *ngIf="!isTouchDevice && slides?.length > 1" (click)="previousSlide()">
        <svg class="chevron" [style.width]="getWidthStyle()" [style.margin-left]="getMarginStyle()"
        xmlns="http://www.w3.org/2000/svg" viewBox="17 15 13 20" enable-background="new 17 15 13 20" fill="#fff">
          <path d="M27.3 34.7L17.6 25l9.7-9.7 1.4 1.4-8.3 8.3 8.3 8.3z"/>
        </svg>
    </div>
    <div class="slider-button right" *ngIf="!isTouchDevice && slides?.length > 1" (click)="nextSlide()">
      <svg class="chevron right" [style.width]="getWidthStyle()" [style.margin-right]="getMarginStyle()"
      xmlns="http://www.w3.org/2000/svg" viewBox="17 15 13 20" enable-background="new 17 15 13 20" fill="#fff">
          <path d="M27.3 34.7L17.6 25l9.7-9.7 1.4 1.4-8.3 8.3 8.3 8.3z"/>
        </svg>
    </div>
    <div class="slider-pagination" *ngIf="slides?.length > 1">
      <div *ngFor="let slide of slidesForPagination; index as index;" (click)="goToSlide(slide)">
        <div class="slider-page" [ngClass]="{ 'is-active': isActive(slide) }"></div>
      </div>
    </div>
  </div>
  `,
                styles: [".slider-wrapper{overflow:hidden;width:100%;height:100%;position:relative}.slider{display:flex;height:100%}.slider.is-animating{transition:transform .4s cubic-bezier(.5,0,.5,1)}.slider-panel{width:100%;background-position:50%;background-repeat:no-repeat;background-size:cover}.slider-button{position:absolute;opacity:.7;height:100%;top:0;width:50%;cursor:pointer}.slider-button:hover{color:#fff;opacity:1}.slider-button.left{left:0}.slider-button.left:hover{background:linear-gradient(270deg,hsla(0,0%,100%,0),hsla(0,0%,100%,.3))}.slider-button.right{right:0}.slider-button.right:hover{background:linear-gradient(90deg,hsla(0,0%,100%,0),hsla(0,0%,100%,.3))}.slider-button .chevron{position:absolute;top:50%;transform:translateY(-50%)}.slider-button .chevron.right{right:0;transform:translateY(-50%) rotate(180deg)}.slider-pagination{bottom:6.25%;left:0;position:absolute;text-align:center;width:100%}.slider-pagination>div{padding:4px;display:inline-block;cursor:pointer}.slider-pagination .slider-page{border-radius:50%;box-shadow:0 0 0 2px hsla(0,0%,100%,.75);height:6px;transition:background-color .25s;width:6px}.slider-pagination .slider-page.is-active{background-color:hsla(0,0%,100%,.75)}"]
            },] }
];
HammerjsCarouselComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
HammerjsCarouselComponent.propDecorators = {
    slides: [{ type: Input }],
    maxNumberOfVisibileInPagination: [{ type: Input }],
    sliderWrapper: [{ type: ViewChild, args: ['sliderWrapper',] }]
};

class GestureConfigService extends HammerGestureConfig {
    buildHammer(element) {
        const mc = new Hammer(element, {
            touchAction: 'pan-y',
            recognizers: [
                [Hammer.Pan],
            ]
        });
        return mc;
    }
}
GestureConfigService.ɵprov = i0.ɵɵdefineInjectable({ factory: function GestureConfigService_Factory() { return new GestureConfigService(); }, token: GestureConfigService, providedIn: "root" });
GestureConfigService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];

class HammerjsCarouselModule {
}
HammerjsCarouselModule.decorators = [
    { type: NgModule, args: [{
                declarations: [HammerjsCarouselComponent],
                imports: [
                    BrowserModule, HammerModule
                ],
                exports: [HammerjsCarouselComponent],
                providers: [{
                        provide: HAMMER_GESTURE_CONFIG,
                        useClass: GestureConfigService
                    }]
            },] }
];

/*
 * Public API Surface of ngx-hammerjs-carousel
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HammerjsCarouselComponent, HammerjsCarouselModule, GestureConfigService as ɵa };
//# sourceMappingURL=ngx-hammerjs-carousel.js.map
